@@ -391,7 +391,7 @@ private:
  */
 class TreeMapWidget: public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
