@@ -132,7 +132,7 @@ TQChar delimiter()
 
 bool SearchBarPlugin::eventFilter(TQObject *o, TQEvent *e)
 {
-	if( TQT_BASE_OBJECT(o)==TQT_BASE_OBJECT(m_searchCombo->lineEdit()) && e->type() == TQEvent::KeyPress ) 
+	if( o==m_searchCombo->lineEdit() && e->type() == TQEvent::KeyPress )
 	{
 		TQKeyEvent *k = (TQKeyEvent *)e;
 		TQString text = k->text();
@@ -537,13 +537,9 @@ void SearchBarPlugin::updateComboVisibility()
 
 void SearchBarPlugin::focusSearchbar()
 {
-#ifdef USE_QT4
-	m_searchCombo->setFocus();
-#else // USE_QT4
 	TQFocusEvent::setReason( TQFocusEvent::Shortcut );
 	m_searchCombo->setFocus();
 	TQFocusEvent::resetReason();
-#endif // USE_QT4
 }
 
 SearchBarCombo::SearchBarCombo(TQWidget *parent, const char *name) :
