@@ -36,7 +36,7 @@ class TDEConfig;
  */
 class MainWidget: public MainWidget_base
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     MainWidget( TDEConfig * config, TQWidget * parent );
